CHANGES
=======
0.0.8
-----
- Fixed bug with rendering doc strings where you define ``attr`` and
  ``request_method``

0.0.7
-----

- New feature to link from endpoints to corresponding view source code.
- Fix missing backslash for route patterns with regexes
